@@ -239,9 +239,10 @@ class Postgres_Handler:
         value_dict = {key: value for key, value in keywords.items() if key.lower() == id_key.lower()}
         
         #Builds query to run 
-        query_string = 'DELETE FROM {table_name} WHERE ID = {Id}'
+        query_string = 'DELETE FROM {table_name} WHERE {column_name} = {Id}'
         sql_query = sql.SQL(query_string).format(
             table_name = sql.Identifier(keywords[table_name_key]),
+            column_name = sql.Identifier(id_key),
             Id= sql.Placeholder(id_key)
         )
         
